'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports['default'] = logRender;
var countRender = new Map();

function updateCountRender(componentId) {
  var count = countRender.get(componentId) || 0;
  count++;
  countRender.set(componentId, count);

  return count;
}

function inArray(componentName, list) {
  return list.some(function (item) {
    if (componentName === item) {
      return true;
    }
  });
}

function logRender(_ref) {
  var components = _ref.components;
  var imports = _ref.imports;

  var options = imports[0];
  return function wrap(ReactClass, componentId) {
    var originalRender = ReactClass.prototype.render;
    var displayName = components[componentId].displayName;
    var enableLog = true;

    if (options) {
      enableLog = options.include ? enableLog && inArray(displayName, options.include) : enableLog;
      enableLog = options.exclude ? enableLog && !inArray(displayName, options.exclude) : enableLog;
    }

    if (enableLog) {
      ReactClass.prototype.render = function () {
        var count = updateCountRender(componentId);
        console.groupCollapsed('render: ' + displayName + ' (' + count + ')');
        console.log('props', this.props);
        console.log('state', this.state);
        console.groupEnd();

        return originalRender.apply(this, arguments);
      };
    }

    return ReactClass;
  };
}

module.exports = exports['default'];